@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm,v 1.92 2006/05/29 19:05:40 mbarbon Exp $
-## Copyright:   (c) 2000-2006 Mattia Barbon
+## RCS-ID:      $Id: Wx.pm 2552 2009-05-10 07:59:43Z mbarbon $
+## Copyright:   (c) 2000-2009 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $XS_VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.49_07';
+$VERSION = '0.91_01';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -41,6 +41,7 @@ sub AUTOLOAD {
   my( $constname );
 
   ($constname = $AUTOLOAD) =~ s<^.*::>{};
+  return 0 if $constname eq 'wxVERSION';
 
   my( $val ) = constant($constname, 0 );
 
@@ -76,7 +77,7 @@ sub import {
 }
 
 sub END {
-  UnLoad();
+  UnLoad() if defined &UnLoad;
 }
 
 sub _match(\@$;$$) { &_xsmatch( [@{shift()}],@_ ) }
@@ -128,7 +129,7 @@ sub _unload_dll { }
 
 sub _load_dll {
   local $ENV{PATH} = $wx_path . ';' . $ENV{PATH} if $wx_path;
-  return unless exists $Wx::dlls->{$_[0]};
+  return unless exists $Wx::dlls->{$_[0]} && $Wx::dlls->{$_[0]};
   my $dll = $Wx::dlls->{$_[0]};
   $dll = $wx_path . '/' . $dll if $wx_path;
   Wx::_load_file( $dll );
@@ -146,9 +147,6 @@ sub _load_dll {
 #
 # British vs. American spelling aliases
 #
-*Wx::SystemSettings::GetColour = \&Wx::SystemSettings::GetSystemColour;
-*Wx::SystemSettings::GetFont   = \&Wx::SystemSettings::GetSystemFont;
-*Wx::SystemSettings::GetMetric = \&Wx::SystemSettings::GetSystemMetric;
 *Wx::Window::Center = \&Wx::Window::Centre;
 *Wx::Window::CenterOnParent = \&Wx::Window::CentreOnParent;
 *Wx::Window::CenterOnScreen = \&Wx::Window::CentreOnScreen;
@@ -160,15 +158,16 @@ use strict 'refs';
 
 *Wx::Window::GetClientSizeWH = \&Wx::Window::GetClientSizeXY;
 
-Load();
-SetConstants();
-SetConstantsOnce();
-SetOvlConstants();
-SetEvents();
-SetInheritance();
+if( Load() ) {
+    SetConstants();
+    SetConstantsOnce();
+    SetOvlConstants();
+    SetEvents();
+    SetInheritance();
+}
 
 sub END {
-  UnsetConstants();
+  UnsetConstants() if defined &UnsetConstants;
 }
 
 #
@@ -182,12 +181,16 @@ eval( "sub wxGTK() { $_platform == $_gtk }" );
 eval( "sub wxMAC() { $_platform == $_mac }" );
 eval( "sub wxX11() { $_platform == $_x11 }" );
 
+# Mac OS X warning
+if( wxMAC() && $^X !~ m{/wxPerl\.app/} && !$ENV{HARNESS_ACTIVE} ) {
+    warn "On Mac OS X please run scripts with the 'wxPerl' interpreter\n";
+}
+
 require Wx::App;
 require Wx::Event;
 require Wx::Locale;
 require Wx::Menu;
 require Wx::RadioBox;
-require Wx::Region;
 require Wx::Timer;
 require Wx::Wx_Exp;
 # for Wx::Stream & co.
@@ -199,20 +202,25 @@ package Wx::Object;    # likewise
 #
 # overloading for Wx::TreeItemId
 #
+package Wx;
+
+sub _string { overload::StrVal( $_[0] ) }
+sub _number { require Scalar::Util; Scalar::Util::refaddr( $_[0] ) }
+
 package Wx::TreeItemId;
 
 use overload '<=>'      => \&tiid_spaceship,
              'bool'     => sub { $_[0]->IsOk },
-             '""'       => sub { $_[0] },
-             '0+'       => sub { $_[0] },
+             '""'       => \&Wx::_string,
+             '0+'       => \&Wx::_number,
              'fallback' => 1;
 
 package Wx::Font;
 
 use overload '<=>'      => \&font_spaceship,
-             'bool'     => sub { $_[0]->Ok },
-             '""'       => sub { $_[0] },
-             '0+'       => sub { $_[0] },
+             'bool'     => sub { $_[0]->IsOk },
+             '""'       => \&Wx::_string,
+             '0+'       => \&Wx::_number,
              'fallback' => 1;
 
 #
@@ -295,6 +303,11 @@ sub Wx::Log::SetTimestamp {
     Wx::Log::_SetTimestamp( $_[0], $ts_buf );
 }
 
+package Wx::PlThreadEvent;
+
+our %stash : shared;
+SetStash( \%stash );
+
 1;
 
 __END__
@@ -307,6 +320,12 @@ Wx - interface to the wxWidgets cross-platform GUI toolkit
 
     use Wx;
 
+    my $app = Wx::SimpleApp->new;
+    my $frame = Wx::Frame->new( undef, -1, 'Hello, world!' );
+
+    $frame->Show;
+    $app->MainLoop;
+
 =head1 DESCRIPTION
 
 The Wx module is a wrapper for the wxWidgets (formerly known as wxWindows)
@@ -317,7 +336,7 @@ can download it from http://wxperl.sourceforge.net/
 
 =head1 INSTALLATION
 
-Please see F<docs/install.txt> in source package.
+Please see F<docs/INSTALL.pod> in source package.
 
 =head1 Windows XP look
 
@@ -353,6 +372,11 @@ must be placed in the same directory as the executable file.
 
 Mattia Barbon <mbarbon@cpan.org>
 
+=head1 LICENSE
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
 =cut
 
 # Local variables: #
