@@ -12,7 +12,7 @@ our $alien_key = 'XXXALIENXXX';
     $Wx::dlls = XXXDLLSXXX;
 }
 
-$VERSION = '0.49_07'; # bootstrap will catch wrong versions
+$VERSION = '0.91_01'; # bootstrap will catch wrong versions
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -43,9 +43,10 @@ sub wx_boot($$) {
 
 sub _alien_path {
   return if defined $wx_path;
+  return unless length 'XXXALIENDXXX';
   foreach ( @INC ) {
-    if( -d "$_/Alien/wxWidgets/XXXALIENXXX" ) {
-      $wx_path = "$_/Alien/wxWidgets/XXXALIENXXX/lib";
+    if( -d "$_/Alien/wxWidgets/XXXALIENDXXX" ) {
+      $wx_path = "$_/Alien/wxWidgets/XXXALIENDXXX/lib";
       last;
     }
   }
